@@ -33,7 +33,6 @@ import math
 from sklearn.cluster import KMeans
 from sklearn.preprocessing import MinMaxScaler, StandardScaler
 from sklearn.metrics import silhouette_score
-
 def last(a,e):
     RI_dict = {1: 0, 2: 0, 3: 0.58, 4: 0.90, 5: 1.12, 6: 1.24, 7: 1.32, 8: 1.41, 9: 1.45}
     def get_w(array):
@@ -53,15 +52,19 @@ def last(a,e):
         # print(max_max)
         CI = (max_max - row) / (row - 1)
         CR = CI / RI_dict[row]
+        print("一致性检验指标为",CR)
         if CR < 0.1:
-            # print(round(CR, 3))
-            # print('满足一致性')
-            # print(np.max(w))
-            # print(sorted(w,reverse=True))
-            # print(max_max)
-            # print('特征向量:%s' % w)
+
+            print(round(CR, 3))
+            print('满足一致性')
+            print(np.max(w))
+            print(sorted(w,reverse=True))
+            print(max_max)
+            print('特征向量:%s' % w)
             return w
         else:
+            print("警告！！！")
+            print(array)
             print(round(CR, 3))
             print('不满足一致性，请进行修改')
 
@@ -115,11 +118,7 @@ def last(a,e):
         # f = np.array([
         #     [1, 1 / 2, 1 / 3],
         #     [2, 1, 1],
-        #     [3, 1, 1]])
-
-
-
-
+        #     [3, 1, 1]]
 def panding(data):
     SSE = []  # 存放每次结果的误差平方和
     for k in range(1, 9):
@@ -147,7 +146,6 @@ def r_julei(data):
     print(data.corr())
     print("请使用r")
     print("dev.new()\nX<-read.table('clipboda',header=T)\n=cor(X) \nhc<-hclust(d)\nplot(hc)")
-
 def cengci_julei(data1,group_size):
     z_scaler = preprocessing.StandardScaler()
     print("如果列的坐标混乱，要先使用排列方法使得，数据以一定的顺序进行查找，方便查找和使用。")
@@ -200,8 +198,6 @@ Average link\
 
     print(dendrogram(Z))
     plt.savefig("聚类分线图2.png")
-
-
 ### 指数曲线法（三段和值）
 def e_fit(input_list):
     tmp = input_list
@@ -239,14 +235,9 @@ def log_fit(input_list):
     def e_fit_pre(t):
         return k + a * (b ** t)
     return e_fit_pre
-
-
-
-
 ### 逻辑曲线进行预测
 def log_pre(a,b,k,t):
     return 1/(k+a*(b**t))
-
 def e_smooth_next(list_input,tmp,alpha):
     a = list_input[-1]
     b = tmp[-1]
@@ -320,8 +311,6 @@ def yieryidong(aa,day,alpha,late = 1):
     smooth_next(np.array(a['mean_1']), np.array(a['mean_2']), day, late)
     print("一次平均法进行预测往后1期")
     smooth_next(np.array(a['x']), np.array(a['mean_1']), day, late)
-
-
 def judge(x):
     import pandas as pd
     import numpy as np
@@ -369,7 +358,6 @@ def judge(x):
                     print("变量", i, "与", j, "方差具有齐性")
                 else:
                     print("变量", i, "与", j, "方差不具有齐性")
-
 def Regression(pddata):
     # 要保证传入的pddata的列名字已经修改为指定的值
     import pandas as pd
@@ -468,7 +456,11 @@ def makemodel(X1,y):
     print("首先进行模型的主观假设检验")
     print("基本假定:"
           "β！=0")
-
+    print("R检验")
+    print("R值为",model.rsquared)
+    print("t检验")
+    print("t值为",model.tvalues)
+    print("如果p>|t|这一列<=0.05,说明通过t检验，拒绝原假设")
     print("F检验")
     print("p值为", model.f_pvalue)
     if model.f_pvalue < 0.05:
